@@ -9,13 +9,6 @@ pub struct AdminCancelTask<'info> {
     #[account(mut, address = config.admin)]
     pub admin: Signer<'info>,
 
-    #[account(
-        seeds = [SEED_AUTHORITY], 
-        bump = authority.bump, 
-        owner = crate::ID
-    )]
-    pub authority: Account<'info, Authority>,
-
     #[account(
         seeds = [SEED_CONFIG],
         bump = config.bump,
@@ -23,17 +16,6 @@ pub struct AdminCancelTask<'info> {
     )]
     pub config: Account<'info, Config>,
 
-    #[account(
-        seeds = [
-            SEED_DAEMON, 
-            daemon.owner.as_ref()
-        ],
-        bump = daemon.bump,
-        constraint = daemon.owner == authority.key(),
-        owner = crate::ID,
-    )]
-    pub daemon: Account<'info, Daemon>,
-
     #[account(
         mut,
         seeds = [
@@ -42,7 +24,6 @@ pub struct AdminCancelTask<'info> {
             task.int.to_be_bytes().as_ref(),
         ],
         bump = task.bump,
-        constraint = task.daemon == daemon.key(),
         owner = crate::ID
     )]
     pub task: Account<'info, Task>,
